
namespace el3 {
class Random;
class Mapbase;
}

void intreg1(el3::Mapbase *m,el3::Random *rg);
void stromtest1(el3::Mapbase *m,el3::Random *rg);
void lab(el3::Mapbase *m,el3::Random *rg);
void hole(el3::Mapbase *m,el3::Random *rg);
void stamp(el3::Mapbase *m,el3::Random *rg);
void pyr(el3::Mapbase *m,el3::Random *rg);

void invert(el3::Mapbase *m,el3::Random *rg);
void randomize_height(el3::Mapbase *m,el3::Random *rg);
